"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_tag_1 = require("graphql-tag");
var chai = require("chai");
var api_gw_connector_1 = require("./api-gw-connector");
var assert = chai.expect;
describe('AWS API GW network interface', function () {
    var simpleQueryWithNoVars = (_a = ["\n    query people {\n      allPeople(first: 1) {\n        people {\n          name\n        }\n      }\n    }\n  "], _a.raw = ["\n    query people {\n      allPeople(first: 1) {\n        people {\n          name\n        }\n      }\n    }\n  "], graphql_tag_1.default(_a));
    var simpleResult = {
        data: {
            allPeople: {
                people: [
                    {
                        name: 'Luke Skywalker',
                    },
                ],
            },
        },
    };
    describe('making a request', function () {
        var clientSet = true;
        var awsApiGwClient = {
            isAuthenticated: function () {
                return clientSet;
            },
            authenticationExpired: function () {
                clientSet = false;
            },
            graphqlPost: function (param, body, extra) {
                assert(JSON.stringify(body)).to.equal('{"query":"query people {\\n  allPeople(first: 1) {\\n    people {\\n      name\\n    }\\n  }\\n}\\n","variables":{},"debugName":"People query"}');
                return Promise.resolve({
                    data: simpleResult,
                    status: 200,
                    statusText: 'OK',
                });
            },
        };
        var awsApiGwClientError = {
            isAuthenticated: function () {
                return clientSet;
            },
            authenticationExpired: function () {
                clientSet = false;
            },
            graphqlPost: function (param, body, extra) {
                assert(JSON.stringify(body)).to.equal('{"query":"query people {\\n  allPeople(first: 1) {\\n    people {\\n      name\\n    }\\n  }\\n}\\n","variables":{},"debugName":"People query"}');
                return Promise.resolve({
                    data: 'Unauthorized',
                    status: 401,
                    statusText: 'Unauthorized',
                });
            },
        };
        var networkInterface = new api_gw_connector_1.AwsApiGwNetworkInterface(awsApiGwClient);
        var networkInterfaceError = new api_gw_connector_1.AwsApiGwNetworkInterface(awsApiGwClientError);
        var simpleRequest = {
            query: simpleQueryWithNoVars,
            variables: {},
            debugName: 'People query',
        };
        it('should fetch remote data', function () {
            networkInterface.query(simpleRequest).then(function (res) {
                return assert(res).to.equal(simpleResult);
            });
        });
        it('should throw an error when client AWS API GW not ready', function () {
            clientSet = false;
            return networkInterface.query(simpleRequest).catch(function (err) {
                assert(err.message).to.equal('AWS API GW client not ready/authenticated !');
            });
        });
        it('should call authenticationExpired() when authentication is wrong/expired', function () {
            clientSet = true;
            return networkInterfaceError.query(simpleRequest).catch(function (err) {
                assert(err.response).to.be;
                assert(err.message).to.equal('Network request failed with status 401 - "Unauthorized"');
                assert(clientSet).to.equal(false);
            });
        });
    });
    var _a;
});
//# sourceMappingURL=api-gw-connector.spec.js.map